/**
 * Copyright (c) 2022 - present TinyVue Authors.
 * Copyright (c) 2022 - present Huawei Cloud Computing Technologies Co., Ltd.
 *
 * Use of this source code is governed by an MIT-style license.
 *
 * THE OPEN SOURCE SOFTWARE IN THIS PRODUCT IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL,
 * BUT WITHOUT ANY WARRANTY, WITHOUT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY OR FITNESS FOR
 * A PARTICULAR PURPOSE. SEE THE APPLICABLE LICENSES FOR MORE DETAILS.
 *
 */
interface TooltipDirectiveConfig {
    always?: boolean;
    content?: string;
    effect?: 'dark' | 'light';
    placement?: string;
}
/** v-auto-tip 绑定值。 支持 falsy值 或 TooltipDirectiveConfig 值， 当传入falsy值时，表示禁用tooltip */
type BoundingValueType = undefined | false | TooltipDirectiveConfig;
/** v-auto-tip 指令
1、基本使用
v-auto-tip
v-auto-tip="false"
v-auto-tip="{always:true, content:'123', effect:'dark'}"
v-auto-tip="{always:true, content:'123', effect:'dark',placement:'right'}"

2、动态切换
v-auto-tip="enabled? {always:true, content:'123', effect:'dark'} : false "

** 修改enabled, 可以让tooltip动态提示

3、自定义content
v-auto-tip="{content:h('span','1234' )}" // 单个vnode
v-auto-tip="{content:[h('span','1234' ), h('span','5678' ) ]}" // 多vnode
v-auto-tip="{content:h('span',{innerHTML:'1234<a>5678</a>'})}" // vue3写法：支持动态 html
v-auto-tip="{content:h('span',{domProps:{ innerHTML:'12345678'}})}" // 如果使用common里的h：支持动态 html

** content 支持一个有效的字符串或vnode|vnode[]
 */
declare const _default: {
    bind: (el: any, { value }: {
        value: BoundingValueType;
    }) => void;
    unbind: (el: any) => void;
    update: (el: any, { value }: {
        value: BoundingValueType;
    }) => void;
    beforeMount: (el: any, { value }: {
        value: BoundingValueType;
    }) => void;
    unmounted: (el: any) => void;
    updated: (el: any, { value }: {
        value: BoundingValueType;
    }) => void;
};
export default _default;
